MSDL atlas


Notes
-----
Result maps of sparse dictionary learning based on resting-state data.

This can be understand as a variant of ICA based on the assumption
of sparsity rather than independence.


Content
-------
    :'maps': Nifti images with the (probabilistic) region definitions
    :'labels': CSV file specifying the label information


References
----------
For more information about this dataset's structure:
https://team.inria.fr/parietal/research/spatial_patterns/spatial-patterns-in-resting-state/

Multi-subject dictionary learning to segment an atlas of brain spontaneous activity Gaël Varoquaux, Alexandre Gramfort, Fabian Pedregosa, Vincent Michel, Bertrand Thirion Information Processing in Medical Imaging, 2011, pp. 562-573, Lecture Notes in Computer Science

Learning and comparing functional connectomes across subjects. Gaël Varoquaux, R.C. Craddock NeuroImage, 2013

Licence: usage is unrestricted for non-commercial research purposes.